==> huaweicloudsdkiamaccessanalyzer-3.1.115-py2.py3-none-any.whl: huaweicloudsdkiamaccessanalyzer/v1/model/untag_resource_req_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UntagResourceReqBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'tag_keys': 'list[str]'
    }

    attribute_map = {
        'tag_keys': 'tag_keys'
    }

    def __init__(self, tag_keys=None):
        """UntagResourceReqBody

        The model defined in huaweicloud sdk

        :param tag_keys: 待删除的标签键列表。
        :type tag_keys: list[str]
        """
        
        

        self._tag_keys = None
        self.discriminator = None

        self.tag_keys = tag_keys

    @property
    def tag_keys(self):
        """Gets the tag_keys of this UntagResourceReqBody.

        待删除的标签键列表。

        :return: The tag_keys of this UntagResourceReqBody.
        :rtype: list[str]
        """
        return self._tag_keys

    @tag_keys.setter
    def tag_keys(self, tag_keys):
        """Sets the tag_keys of this UntagResourceReqBody.

        待删除的标签键列表。

        :param tag_keys: The tag_keys of this UntagResourceReqBody.
        :type tag_keys: list[str]
        """
        self._tag_keys = tag_keys

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UntagResourceReqBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiamaccessanalyzer-3.1.152-py2.py3-none-any.whl: huaweicloudsdkiamaccessanalyzer/v1/model/untag_resource_req_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UntagResourceReqBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'tag_keys': 'list[str]'
    }

    attribute_map = {
        'tag_keys': 'tag_keys'
    }

    def __init__(self, tag_keys=None):
        r"""UntagResourceReqBody

        The model defined in huaweicloud sdk

        :param tag_keys: 待删除的标签键列表。
        :type tag_keys: list[str]
        """
        
        

        self._tag_keys = None
        self.discriminator = None

        self.tag_keys = tag_keys

    @property
    def tag_keys(self):
        r"""Gets the tag_keys of this UntagResourceReqBody.

        待删除的标签键列表。

        :return: The tag_keys of this UntagResourceReqBody.
        :rtype: list[str]
        """
        return self._tag_keys

    @tag_keys.setter
    def tag_keys(self, tag_keys):
        r"""Sets the tag_keys of this UntagResourceReqBody.

        待删除的标签键列表。

        :param tag_keys: The tag_keys of this UntagResourceReqBody.
        :type tag_keys: list[str]
        """
        self._tag_keys = tag_keys

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UntagResourceReqBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
